Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3717)

Unified Diff: chrome/browser/instant/instant_page.h

Issue 12047107: Change the SearchBox API from using the start/end margins of the location bar to using the start ma… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sync Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_page.h
diff --git a/chrome/browser/instant/instant_page.h b/chrome/browser/instant/instant_page.h
index 22565249edd20591b8a6336da9a73c0de8997d7a..22f4eacce1c816da8353b903573d696ff27c6af7 100644
--- a/chrome/browser/instant/instant_page.h
+++ b/chrome/browser/instant/instant_page.h
@@ -121,10 +121,10 @@ class InstantPage : public content::WebContentsObserver {
// by the omnibox dropdown.
void SetPopupBounds(const gfx::Rect& bounds);
// Tells the page the start and end margins of the omnibox (in screen
// coordinates). This is used by the page to align text or assets properly
// with the omnibox.
- void SetMarginSize(int start, int end);
+ void SetStartMarginAndWidth(int start, int width);
// Tells the page about the font information.
void InitializeFonts();
@@ -121,10 +121,10 @@ class InstantPage : public content::WebContentsObserver {
// by the omnibox dropdown.
void SetPopupBounds(const gfx::Rect& bounds);
- // Tells the page the start and end margins of the omnibox (in screen
+ // Tells the page the start margin and width of the omnibox (in screen
// coordinates). This is used by the page to align text or assets properly
// with the omnibox.

Powered by Google App Engine
This is Rietveld 408576698